package io.scanbot.sdk.plugin.cordova

import android.content.Intent
import io.scanbot.sdk.sdk_native_wrapper.SBNWReadyToUseUi
import io.scanbot.sdk.sdk_native_wrapper.withConfiguration
import io.scanbot.sdk.sdk_native_wrapper.wrapper.ui.base.SBNWRtuWrapper
import org.apache.cordova.CallbackContext
import org.apache.cordova.CordovaPlugin
import org.json.JSONArray


class ScanbotSDKUIPlugin : CordovaPlugin() {

  private val readyToUseUi: SBNWReadyToUseUi = SBNWReadyToUseUi()
  private val codeContextMap: MutableMap<Int, Pair<SBNWRtuWrapper<*, *>, CallbackContext>> =
    mutableMapOf()

  enum class ScannerActivityCodes(val code: Int) {
    DOCUMENT_SCANNER(1000),
    FINDER_DOCUMENT_SCANNER(1001),
    CROPPING_SCREEN(1002),
    MRZ_SCANNER(1003),
    BARCODE_SCANNER(1004),
    BATCH_BARCODE_SCANNER(1005),
    EHIC_SCANNER(1006),
    TEXT_DATA_SCANNER(1007),
    LICENCE_PLATE_SCANNER(1008),
    MEDICAL_CERTIFICATE_RECOGNIZER(1009),
    GENERIC_DOCUMENT_SCANNER(1010),
    CHECK_RECOGNIZER(1011),
    VIN_SCANNER(1012);
  }

  override fun execute(
    action: String?,
    args: JSONArray?,
    callbackContext: CallbackContext?
  ): Boolean {

    if (args === null || action === null || callbackContext === null) {
      return false
    }

    val configuration = args.optItemToMap("uiConfigs") ?: mapOf()

    return when (action) {
      "startDocumentScanner" -> {
        startRtuUiActivity(
          readyToUseUi.documentScanner.withConfiguration(configuration),
          ScannerActivityCodes.DOCUMENT_SCANNER,
          callbackContext
        )
        return true
      }

      "closeDocumentScanner" -> {
        closeRtuUiActivity(readyToUseUi.documentScanner, callbackContext)
        return true
      }

      "startCroppingScreen" -> {
        val page = args.itemToMap("page")
        startRtuUiActivity(
          readyToUseUi.croppingScreen.withConfiguration(page, configuration),
          ScannerActivityCodes.CROPPING_SCREEN,
          callbackContext
        )
        return true
      }

      "closeCroppingScreen" -> {
        closeRtuUiActivity(readyToUseUi.croppingScreen, callbackContext)
        return true
      }

      "startMrzScanner" -> {
        startRtuUiActivity(
          readyToUseUi.mrzScanner.withConfiguration(configuration),
          ScannerActivityCodes.MRZ_SCANNER,
          callbackContext
        )
        return true
      }

      "closeMrzScanner" -> {
        closeRtuUiActivity(readyToUseUi.mrzScanner, callbackContext)
        return true
      }

        "startBarcodeScanner" -> {
          try {
            startRtuUiActivity(
              readyToUseUi.barcodeScanner.withConfiguration(configuration),
              ScannerActivityCodes.BARCODE_SCANNER,
              callbackContext
            )
          } catch (error: Exception) {
            callbackContext.error(error.message)
          }
          return true
        }

      "closeBarcodeScanner" -> {
        closeRtuUiActivity(readyToUseUi.barcodeScanner, callbackContext)
        return true
      }

        "startBatchBarcodeScanner" -> {
          try {
            startRtuUiActivity(
              readyToUseUi.barcodesBatchScanner.withConfiguration(configuration),
              ScannerActivityCodes.BATCH_BARCODE_SCANNER,
              callbackContext
            )
          } catch (error: Exception) {
             callbackContext.error(error.message)
          }
          return true
        }

      "closeBatchBarcodeScanner" -> {
        closeRtuUiActivity(readyToUseUi.barcodesBatchScanner, callbackContext)
        return true
      }

      "startEHICScanner" -> {
        startRtuUiActivity(
          readyToUseUi.ehicScanner.withConfiguration(configuration),
          ScannerActivityCodes.EHIC_SCANNER,
          callbackContext
        )
        return true
      }

      "closeEHICScanner" -> {
        closeRtuUiActivity(readyToUseUi.ehicScanner, callbackContext)
        return true
      }

      "startTextDataScanner" -> {
        startRtuUiActivity(
          readyToUseUi.textDataScanner.withConfiguration(configuration),
          ScannerActivityCodes.TEXT_DATA_SCANNER,
          callbackContext
        )
        return true
      }

      "closeTextDataScanner" -> {
        closeRtuUiActivity(readyToUseUi.textDataScanner, callbackContext)
        return true
      }

      "startLicensePlateScanner" -> {
        startRtuUiActivity(
          readyToUseUi.licensePlateScanner.withConfiguration(configuration),
          ScannerActivityCodes.LICENCE_PLATE_SCANNER,
          callbackContext
        )
        return true
      }

      "closeLicensePlateScanner" -> {
        closeRtuUiActivity(readyToUseUi.licensePlateScanner, callbackContext)
        return true
      }

      "startMedicalCertificateRecognizer" -> {
        startRtuUiActivity(
          readyToUseUi.medicalCertificateScanner.withConfiguration(configuration),
          ScannerActivityCodes.MEDICAL_CERTIFICATE_RECOGNIZER,
          callbackContext
        )
        return true
      }

      "closeMedicalCertificateRecognizer" -> {
        closeRtuUiActivity(readyToUseUi.medicalCertificateScanner, callbackContext)
        return true
      }

      "startGenericDocumentRecognizer" -> {
        startRtuUiActivity(
          readyToUseUi.genericDocumentRecognizer.withConfiguration(configuration),
          ScannerActivityCodes.GENERIC_DOCUMENT_SCANNER,
          callbackContext
        )
        return true
      }

      "closeGenericDocumentRecognizer" -> {
        closeRtuUiActivity(readyToUseUi.genericDocumentRecognizer, callbackContext)
        return true
      }

      "startCheckRecognizer" -> {
        startRtuUiActivity(
          readyToUseUi.checkRecognizer.withConfiguration(configuration),
          ScannerActivityCodes.CHECK_RECOGNIZER,
          callbackContext
        )
        return true
      }

      "closeCheckRecognizer" -> {
        closeRtuUiActivity(readyToUseUi.checkRecognizer, callbackContext)
        return true
      }

      "startFinderDocumentScanner" -> {
        startRtuUiActivity(
          readyToUseUi.finderDocumentScanner.withConfiguration(configuration),
          ScannerActivityCodes.FINDER_DOCUMENT_SCANNER,
          callbackContext
        )
        return true
      }

      "closeFinderDocumentScanner" -> {
        closeRtuUiActivity(readyToUseUi.finderDocumentScanner, callbackContext)
        return true
      }

      "startVinScanner" -> {
        startRtuUiActivity(
          readyToUseUi.vinScanner.withConfiguration(configuration),
          ScannerActivityCodes.VIN_SCANNER,
          callbackContext
        )
        return true
      }

      "closeVinScanner" -> {
        closeRtuUiActivity(readyToUseUi.vinScanner, callbackContext)
        return true
      }

      else -> false
    }
  }

  private fun startRtuUiActivity(
    scannerWrapper: SBNWRtuWrapper<*, *>,
    scannerCode: ScannerActivityCodes,
    callbackContext: CallbackContext
  ) {
    cordova.threadPool.run {
      val intent = scannerWrapper.createIntent(cordova.context)
      codeContextMap[scannerCode.code] = Pair(scannerWrapper, callbackContext)
      cordova.startActivityForResult(this@ScanbotSDKUIPlugin, intent, scannerCode.code)
    }
  }

  private fun closeRtuUiActivity(
    scannerWrapper: SBNWRtuWrapper<*, *>,
    callbackContext: CallbackContext?
  ) {
    cordova.threadPool.run {
      scannerWrapper.close(cordova.context)
      callbackContext?.success()
    }
  }

  override fun onActivityResult(requestCode: Int, resultCode: Int, intent: Intent?) {

    codeContextMap[requestCode]?.let {
      val (scannerWrapper, callbackContext) = it

      scannerWrapper.handleResult(
        ResultDelegate(callbackContext),
        resultCode,
        intent
      )
    } ?: run {
      super.onActivityResult(requestCode, resultCode, intent)
    }

  }

}
