
import Foundation
import ScanbotSDKNativeWrapper
import ScanbotSDK

@objc(ScanbotSDKUIPlugin) class ScanbotSDKUIPlugin : CDVPlugin {

    var documentScanner: SBSDKUIDocumentScannerViewController?
    var finderDocumentScanner: SBSDKUIFinderDocumentScannerViewController?
    var mrzScanner: SBSDKUIMRZScannerViewController?
    var checkRecognizer: SBSDKUICheckRecognizerViewController?
    var barcodeScanner: SBSDKUIBarcodeScannerViewController?
    var textDataScanner: SBSDKUITextDataScannerViewController?
    var genericDocumentRecognizer: SBSDKUIGenericDocumentRecognizerViewController?
    var batchBarcodeScanner: SBSDKUIBarcodesBatchScannerViewController?
    var ehicScanner: SBSDKUIHealthInsuranceCardScannerViewController?
    var licensePlateScanner: SBSDKUILicensePlateScannerViewController?
    var medicalCertificateRecognizer: SBSDKUIMedicalCertificateScannerViewController?
    var croppingScreen: SBSDKUICroppingViewController?
    var vinScanner: SBSDKUIVINScannerViewController?

    let configsKey = "uiConfigs"

    func sendError(callbackId: String, message: String){
        self.commandDelegate.send(
            CDVPluginResult(
                status: CDVCommandStatus_ERROR,
                messageAs: [
                    "message":message
                ]
            ),
            callbackId: callbackId)
    }

    func closeScannerSuccessfully(callbackId: String){
        self.commandDelegate.send(
            CDVPluginResult(
                status: CDVCommandStatus_OK
            ),
            callbackId: callbackId)
    }

    func unexpectedError(callbackId: String){
        sendError(callbackId: callbackId, message: "An unexpected error has occurred")
    }

    func conversionError(callbackId: String){
        sendError(callbackId: callbackId, message: "Invalid configuration provided")
    }

    func presentViewController(callbackId: String, vc : UIViewController){
        guard let activeVC = self.viewController else {
            sendError(callbackId: callbackId, message: "Could not find root view controller")
            return
        }

        activeVC.present(vc, animated: true)
    }

    @objc(startDocumentScanner:)
    func startDocumentScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createDocumentScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.documentScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }

    @objc(closeDocumentScanner:)
    func closeDocumentScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.documentScanner?.dismiss(animated: true)
            self.documentScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startCroppingScreen:)
    func startCroppingScreen(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            guard let page = command.itemAtIndexToMap(key: "page") else {
                self.sendError(callbackId: command.callbackId, message: "Required parameter page has not been provided")
                return
            }
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createCroppingScreenViewController(
                withPage: page,
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.croppingScreen = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeCroppingScreen:)
    func closeCroppingScreen(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.croppingScreen?.dismiss(animated: true)
            self.croppingScreen = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startMrzScanner:)
    func startMrzScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createMrzScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.mrzScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeMrzScanner:)
    func closeMrzScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.mrzScanner?.dismiss(animated: true)
            self.mrzScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startBarcodeScanner:)
    func startBarcodeScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createBarcodeScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.barcodeScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeBarcodeScanner:)
    func closeBarcodeScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.barcodeScanner?.dismiss(animated: true)
            self.barcodeScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startBatchBarcodeScanner:)
    func startBatchBarcodeScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createBatchBarcodeScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.batchBarcodeScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeBatchBarcodeScanner:)
    func closeBatchBarcodeScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.batchBarcodeScanner?.dismiss(animated: true)
            self.batchBarcodeScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startEHICScanner:)
    func startEHICScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createEhicScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.ehicScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeEHICScanner:)
    func closeEHICScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.ehicScanner?.dismiss(animated: true)
            self.ehicScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startTextDataScanner:)
    func startTextDataScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createTextDataScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId),
                eventEmitterDelegate: nil
            )
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.textDataScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeTextDataScanner:)
    func closeTextDataScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.textDataScanner?.dismiss(animated: true)
            self.textDataScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startLicensePlateScanner:)
    func startLicensePlateScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createLicensePlateScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.licensePlateScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeLicensePlateScanner:)
    func closeLicensePlateScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.licensePlateScanner?.dismiss(animated: true)
            self.licensePlateScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startMedicalCertificateRecognizer:)
    func startMedicalCertificateRecognizer(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createMedicalCertificateScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.medicalCertificateRecognizer = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeMedicalCertificateRecognizer:)
    func closeMedicalCertificateRecognizer(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.medicalCertificateRecognizer?.dismiss(animated: true)
            self.medicalCertificateRecognizer = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startGenericDocumentRecognizer:)
    func startGenericDocumentRecognizer(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createGenericDocumentRecognizerViewController(
                configuration: configuration,
                imageResultsConfiguration: SBNWImageResultsConfiguration.defaultConfiguration(),
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.genericDocumentRecognizer = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeGenericDocumentRecognizer:)
    func closeGenericDocumentRecognizer(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.genericDocumentRecognizer?.dismiss(animated: true)
            self.genericDocumentRecognizer = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startCheckRecognizer:)
    func startCheckRecognizer(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createCheckRecognizerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.checkRecognizer = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeCheckRecognizer:)
    func closeCheckRecognizer(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.checkRecognizer?.dismiss(animated: true)
            self.checkRecognizer = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startFinderDocumentScanner:)
    func startFinderDocumentScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createFinderDocumentScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.finderDocumentScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeFinderDocumentScanner:)
    func closeFinderDocumentScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.finderDocumentScanner?.dismiss(animated: true)
            self.finderDocumentScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }


    @objc(startVinScanner:)
    func startVinScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            var configuration: [String:Any] = [:]
            if let config = command.itemAtIndexToMap(key: self.configsKey){
                configuration = config
            }
            guard let vc = SBNWReadyToUseUi.createVinScannerViewController(
                configuration: configuration,
                delegate: ResultDelegate(commandDelegate: self.commandDelegate,callbackId: command.callbackId))
            else {
                self.unexpectedError(callbackId: command.callbackId)
                return
            }
            self.vinScanner = vc
            self.presentViewController(callbackId: command.callbackId, vc: vc)
        }
    }


    @objc(closeVinScanner:)
    func closeVinScanner(command: CDVInvokedUrlCommand){
        DispatchQueue.main.async {
            self.vinScanner?.dismiss(animated: true)
            self.vinScanner = nil
            self.closeScannerSuccessfully(callbackId: command.callbackId)
        }
    }

}
