const constants = require('./constants')
const helpers = require('./helpers')

exports.defineAutoTests = function () {
    beforeAll(function() {
        jasmine.DEFAULT_TIMEOUT_INTERVAL = 65000;
    });

    describe('Initialize SDK Scenarios', function () {
        it('SDK Initialized with Trial License, verify license info is Trial', async () => {
            await helpers.initializeSdk(constants.trialLicense);
            await helpers.validateLicense(constants.config.license.trial);
        });

        it('SDK Initialized with Trial License, verify Trial license expires after 60 seconds', async () => {

            function sleep(milliseconds) {
                return new Promise(resolve => setTimeout(resolve, milliseconds))
            }

            // start app with trial license and validate trial license info is correct
            await helpers.initializeSdk(constants.trialLicense);
            await helpers.validateLicense(constants.config.license.trial);

            // wait 61 seconds so that trial license is expired
            await sleep(61000)

            // validate that license is not set
            await helpers.validateLicense(constants.config.license.notSet);
        });

        it('SDK Initialized with Expired License', async () => {
            await helpers.initializeSdk(constants.expiredLicense);
            await helpers.validateLicense(constants.config.license.expired);
        });

        if (device.platform === "Android") {
            it('SDK Initialized with Android only license for Android device', async () => {
                await helpers.initializeSdk(constants.androidLicense);
                await helpers.validateLicense(constants.config.license.correctOs);
            });
            it('SDK Initialization with iOS only license on Android device fails', async () => {
                await helpers.initializeSdk(constants.iosLicense);
                await helpers.validateLicense(constants.config.license.wrongOs);
            });
        }
        if (device.platform === "iOS") {
            it('SDK Initialized with iOS only license for iOS device', async () => {
                await helpers.initializeSdk(constants.iosLicense);
                await helpers.validateLicense(constants.config.license.correctOs);
            });
            it('SDK Initialization with Android only license on iOS device fails', async () => {
                await helpers.initializeSdk(constants.androidLicense);
                await helpers.validateLicense(constants.config.license.wrongOs);
            });
        }

        it('SDK Initialization with a license that has an App ID that does not match the App fails', async () => {
            await helpers.initializeSdk(constants.appIdMismatchLicense);
            await helpers.validateLicense(constants.config.license.appIdMismatch);
        });

        it('SDK Initialization with a corrupted license fails', async () => {
            await helpers.initializeSdk(constants.corruptedLicense);
            await helpers.validateLicense(constants.config.license.corrupted);
        });

        it('SDK Initialized with Valid License', async () => {
            await helpers.initializeSdk(constants.validLicense);
            await helpers.validateLicense(constants.config.license.okay);
        });
    });
};
