
import { GenericDocumentWrapper } from "./gdr-base-wrappers";
import { Field } from "./generic_document_types";


/** MRZ part of the document  */
export interface MRZDocument extends GenericDocumentWrapper {
    /** Unknown */
    unknown?: Field;
    /** Document number */
    documentNumber?: Field;
    /** Issuing authority */
    issuingAuthority?: Field;
    /** Office of issuance */
    officeOfIssuance?: Field;
    /** Date of issuance */
    dateOfIssuance?: Field;
    /** Given names */
    givenNames: Field;
    /** Surname */
    surname: Field;
    /** Nationality */
    nationality: Field;
    /** Birth date */
    birthDate: Field;
    /** Gender */
    gender?: Field;
    /** Expiry date */
    expiryDate?: Field;
    /** Personal number */
    personalNumber?: Field;
    /** Travel document type */
    travelDocType?: Field;
    /** Travel document type variant */
    travelDocTypeVariant?: Field;
    /** Optional 1 */
    optional1?: Field;
    /** Optional 2 */
    optional2?: Field;
    /** Document type code */
    documentTypeCode?: Field;
    /** PIN code */
    pinCode?: Field;
    /** Language code */
    languageCode?: Field;
    /** Version number */
    versionNumber?: Field;
    /** Check digit document number */
    checkDigitDocumentNumber?: Field;
    /** Check digit birth date */
    checkDigitBirthDate?: Field;
    /** Check digit expiry date */
    checkDigitExpiryDate?: Field;
    /** Check digit personal number */
    checkDigitPersonalNumber?: Field;
    /** Check digit general */
    checkDigitGeneral?: Field;
}
/** German ID card, front side  */
export interface DeIdCardFrontDocument extends GenericDocumentWrapper {
    /** Document ID number (in the top-right corner) */
    id: Field;
    /** Surname */
    surname: Field;
    /** Maiden name */
    maidenName?: Field;
    /** Given names */
    givenNames: Field;
    /** Birth date */
    birthDate: Field;
    /** Nationality */
    nationality: Field;
    /** Birthplace */
    birthplace: Field;
    /** Expiry date */
    expiryDate: Field;
    /** PIN */
    pin: Field;
    /** Signature image */
    signature: Field;
}
/** German ID card, back side  */
export interface DeIdCardBackDocument extends GenericDocumentWrapper {
    /** Eye color */
    eyeColor: Field;
    /** Height */
    height: Field;
    /** Issue date */
    issueDate: Field;
    /** Issuing authority */
    issuingAuthority: Field;
    /** Address */
    address: Field;
    /** Pseudonym */
    pseudonym: Field;
    /** Raw MRZ text value */
    rawMRZ: Field;
    /**  Contains the MRZ sub-document. */
    mrz: MRZDocument;
}
/** German travel passport (Reisepass)  */
export interface DePassportDocument extends GenericDocumentWrapper {
    /** Document ID number (in the top-right corner) */
    id: Field;
    /** Surname */
    surname: Field;
    /** Maiden name */
    maidenName?: Field;
    /** Given names */
    givenNames: Field;
    /** Birth date */
    birthDate: Field;
    /** Nationality */
    nationality: Field;
    /** Birthplace */
    birthplace: Field;
    /** Expiry date */
    expiryDate: Field;
    /** Passport type */
    passportType: Field;
    /** Country code */
    countryCode: Field;
    /** Gender */
    gender: Field;
    /** Signature image */
    signature: Field;
    /** Issue date */
    issueDate: Field;
    /** Issuing authority */
    issuingAuthority: Field;
    /** Raw MRZ text value */
    rawMRZ: Field;
    /**  Contains the MRZ sub-document. */
    mrz: MRZDocument;
}
/** German driver license (Führerschein), front side  */
export interface DeDriverLicenseFrontDocument extends GenericDocumentWrapper {
    /** Surname */
    surname: Field;
    /** Given names */
    givenNames: Field;
    /** Birth date */
    birthDate: Field;
    /** Birthplace */
    birthplace: Field;
    /** Issue date */
    issueDate: Field;
    /** Issuing authority */
    issuingAuthority: Field;
    /** Expiry date */
    expiryDate: Field;
    /** Document ID number (in the top-right corner) */
    id: Field;
    /** Signature image */
    signature: Field;
    /** Driver's license categories */
    licenseCategories: Field;
}
/** German driver license (Führerschein), back side  */
export interface DeDriverLicenseBackDocument extends GenericDocumentWrapper {
    /** Restrictions applied for the driver's license */
    restrictions: Field;
    
    /**  Categories table row container  */
    categories: CategoriesDocument;
}
/** A category row from the categories table  */
export interface CategoryDocument extends GenericDocumentWrapper {
    /** Valid from */
    validFrom: Field;
    /** Valid until */
    validUntil: Field;
    /** Restrictions */
    restrictions: Field;
}
/** Categories table row container  */
export interface CategoriesDocument extends GenericDocumentWrapper {
    /**  Contains the A sub-document. */
    a: ADocument;
    /**  Contains the A1 sub-document. */
    a1: A1Document;
    /**  Contains the A2 sub-document. */
    a2: A2Document;
    /**  Contains the B sub-document. */
    b: BDocument;
    /**  Contains the B1 sub-document. */
    b1?: B1Document;
    /**  Contains the BE sub-document. */
    be: BEDocument;
    /**  Contains the C sub-document. */
    c: CDocument;
    /**  Contains the C1 sub-document. */
    c1: C1Document;
    /**  Contains the C1E sub-document. */
    c1e: C1EDocument;
    /**  Contains the CE sub-document. */
    ce: CEDocument;
    /**  Contains the D sub-document. */
    d: DDocument;
    /**  Contains the D1 sub-document. */
    d1: D1Document;
    /**  Contains the D1E sub-document. */
    d1e: D1EDocument;
    /**  Contains the DE sub-document. */
    de: DEDocument;
    /**  Contains the L sub-document. */
    l: LDocument;
    /**  Contains the M sub-document. */
    m: MDocument;
    /**  Contains the T sub-document. */
    t: TDocument;
}
/** The A document. */
export interface ADocument extends CategoryDocument  {
}
/** The A1 document. */
export interface A1Document extends CategoryDocument  {
}
/** The A2 document. */
export interface A2Document extends CategoryDocument  {
}
/** The B document. */
export interface BDocument extends CategoryDocument  {
}
/** The B1 document. */
export interface B1Document extends CategoryDocument  {
}
/** The BE document. */
export interface BEDocument extends CategoryDocument  {
}
/** The C document. */
export interface CDocument extends CategoryDocument  {
}
/** The C1 document. */
export interface C1Document extends CategoryDocument  {
}
/** The C1E document. */
export interface C1EDocument extends CategoryDocument  {
}
/** The CE document. */
export interface CEDocument extends CategoryDocument  {
}
/** The D document. */
export interface DDocument extends CategoryDocument  {
}
/** The D1 document. */
export interface D1Document extends CategoryDocument  {
}
/** The D1E document. */
export interface D1EDocument extends CategoryDocument  {
}
/** The DE document. */
export interface DEDocument extends CategoryDocument  {
}
/** The L document. */
export interface LDocument extends CategoryDocument  {
}
/** The M document. */
export interface MDocument extends CategoryDocument  {
}
/** The T document. */
export interface TDocument extends CategoryDocument  {
}
/** The Check document. */
export interface CheckDocument extends GenericDocumentWrapper {
    /** Detected raw string */
    rawString: Field;
    /** type of check font */
    fontType?: Field;
}
/** A check compatible with the ASC X9 standard used in the USA  */
export interface USACheckDocument extends CheckDocument  {
    /** Auxiliary On-Us */
    auxiliaryOnUs?: Field;
    /** Transit number */
    transitNumber: Field;
    /** Account number */
    accountNumber: Field;
}
/** A check format commonly used in France  */
export interface FRACheckDocument extends CheckDocument  {
    /** Cheque number */
    chequeNumber: Field;
    /** Routing number */
    routingNumber: Field;
    /** Account number */
    accountNumber: Field;
}
/** A check format commonly used in Kuwait  */
export interface KWTCheckDocument extends CheckDocument  {
    /** Cheque number */
    chequeNumber: Field;
    /** Sort code */
    sortCode: Field;
    /** Account number */
    accountNumber: Field;
}
/** A check compatible with the Australian Paper Clearing System cheque standard  */
export interface AUSCheckDocument extends CheckDocument  {
    /** Extra auxiliary domestic */
    extraAuxDomestic?: Field;
    /** Auxiliary domestic */
    auxDomestic?: Field;
    /** BSB */
    bsb: Field;
    /** Account number */
    accountNumber: Field;
    /** Transaction code */
    transactionCode: Field;
}
/** A check compatible with the CTS-2010 standard issued by the Reserve Bank of India in 2012  */
export interface INDCheckDocument extends CheckDocument  {
    /** Serial number */
    serialNumber: Field;
    /** Sort number */
    sortNumber?: Field;
    /** Account number */
    accountNumber: Field;
    /** Transaction code */
    transactionCode: Field;
}
/** A check format commonly used in Israel  */
export interface ISRCheckDocument extends CheckDocument  {
    /** Cheque number */
    chequeNumber: Field;
    /** Bank number */
    bankNumber: Field;
    /** Branch number */
    branchNumber: Field;
    /** Account number */
    accountNumber: Field;
}
/** A check that doesn't conform to any supported standard  */
export interface UnknownCheckDocument extends CheckDocument  {
}
