function cordova_exec(actionName, moduleName) {
    return function (resolve, reject, ...options) {
        try {
            cordova.exec(resolve, reject, moduleName, actionName, (options ?? []));
        } catch (e) {
            reject(JSON.stringify(e))
        }
    };
}

function promisify(fn) {
    return function (...functionArguments) {
        return new Promise(function (resolve, reject) {
            fn(resolve, reject, ...functionArguments);
        });
    }
}

function makeCaller(actionName, promisifyExec) {
    let exec = cordova_exec(actionName, "ScanbotSDK")
    return promisifyExec ? promisify(exec) : exec
}

function makeUICaller(actionName, promisifyExec) {
    let exec = cordova_exec(actionName, "ScanbotSDKUI")
    return promisifyExec ? promisify(exec) : exec
}

let rtuUIFunctions = [
    "startDocumentScanner",
    "closeDocumentScanner",
    "startFinderDocumentScanner",
    "closeFinderDocumentScanner",
    "startCroppingScreen",
    "closeCroppingScreen",
    "startMrzScanner",
    "closeMrzScanner",
    "startBarcodeScanner",
    "closeBarcodeScanner",
    "startBatchBarcodeScanner",
    "closeBatchBarcodeScanner",
    "startEHICScanner",
    "closeEHICScanner",
    "startTextDataScanner",
    "closeTextDataScanner",
    "startLicensePlateScanner",
    "closeLicensePlateScanner",
    "startMedicalCertificateRecognizer",
    "closeMedicalCertificateRecognizer",
    "startGenericDocumentRecognizer",
    "closeGenericDocumentRecognizer",
    "startCheckRecognizer",
    "closeCheckRecognizer",
    "startVinScanner",
    "closeVinScanner"
]

let sdkOperations = [
    "initializeSdk",
    "getLicenseInfo",
    "detectBarcodesOnImage",
    "detectBarcodesOnImages",
    "applyImageFilter",
    "applyImageFilterOnPage",
    "getImageData",
    "rotateImage",
    "createPage",
    "removePage",
    "rotatePage",
    "setDocumentImage",
    "detectDocument",
    "detectDocumentOnPage",
    "documentQualityAnalyzer",
    "extractImagesFromPdf",
    "extractPagesFromPdf",
    "recognizeCheckOnImage",
    "recognizeMrz",
    "refreshImageUris",
    "getOcrConfigs",
    "cleanup",
    "getFilteredDocumentPreviewUri",
    "performOcr",
    "createPdf",
    "writeTiff",
]

const UI = {}

rtuUIFunctions.forEach(fn => {
    UI[fn] = makeUICaller(fn, false)
})
sdkOperations.forEach(op => {
    exports[op] = makeCaller(op, false)
})

exports.promisify = () => {
    const promisified = {}
    const promisifiedUI = {}

    rtuUIFunctions.forEach(fn => {
        promisifiedUI[fn] = makeUICaller(fn, true)
    })

    sdkOperations.forEach(op => {
        promisified[op] = makeCaller(op, true)
    })

    promisified.UI = promisifiedUI

    return promisified
}

exports.UI = UI
